@@ -1,4 +1,4 @@
-"logL.sameMs" <-
+`logL.sameMs` <-
 function (p, y, pool=TRUE)
 # computes logL over >1 sequence, of model in which all sequences have the 
 # same directionality (Mstep), with different step variances
